xclim.sdba package
==================

Submodules
----------

xclim.sdba.adjustment module
----------------------------

.. automodule:: xclim.sdba.adjustment
   :members:
   :undoc-members:
   :show-inheritance:

xclim.sdba.base module
----------------------

.. automodule:: xclim.sdba.base
   :members:
   :undoc-members:
   :show-inheritance:

xclim.sdba.detrending module
----------------------------

.. automodule:: xclim.sdba.detrending
   :members:
   :undoc-members:
   :show-inheritance:

xclim.sdba.processing module
----------------------------

.. automodule:: xclim.sdba.processing
   :members:
   :undoc-members:
   :show-inheritance:

xclim.sdba.utils module
-----------------------

.. automodule:: xclim.sdba.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: xclim.sdba
   :members:
   :undoc-members:
   :show-inheritance:
